# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/model/v1/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/model/v1/model.proto',
  package='github.com.metaprov.modelaapi.services.model.v1',
  syntax='proto3',
  serialized_options=b'Z/github.com/metaprov/modelaapi/services/model/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;github.com/metaprov/modelaapi/services/model/v1/model.proto\x12/github.com.metaprov.modelaapi.services.model.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\")\n\x1a\x43reateModelProfileResponse\x12\x0b\n\x03uri\x18\x03 \x01(\t\"<\n\x19\x43reateModelProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x17ListModelProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"F\n\x16GetModelProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"j\n\x17GetModelProfileResponse\x12O\n\x07profile\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\"\xa2\x01\n\x14GetModelLogsResponse\x12]\n\x04logs\x18\x01 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.LogsEntry\x1a+\n\tLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x13GetModelLogsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x12\x43reateModelRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x15\n\x13\x43reateModelResponse\"c\n\x12UpdateModelRequest\x12M\n\x04item\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x15\n\x13UpdateModelResponse\"o\n\x10GetModelResponse\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"4\n\x11\x41\x62ortModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12\x41\x62ortModelResponse\"4\n\x11PauseModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12PauseModelResponse\"5\n\x12ResumeModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13ResumeModelResponse\"8\n\x14\x43ompareModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8b\x01\n\x15\x43ompareModelsResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12P\n\x08profiles\x18\x03 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\"X\n\x13\x43ompileModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12\x10\n\x08\x63ompiler\x18\x04 \x01(\t\"8\n\x14\x43ompileModelResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x01(\t\"y\n\x12\x44\x65ployModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tpredictor\x18\x03 \x01(\t\x12\x10\n\x08replicas\x18\x04 \x01(\x05\x12\x0f\n\x07traffic\x18\x05 \x01(\x05\x12\x0c\n\x04role\x18\x06 \x01(\t\"6\n\x13PublishModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65ployModelResponse\"\xb5\x01\n\x11ListModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x12ListModelsResponse\x12R\n\x05items\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelList\"2\n\x0fGetModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x13\n\x11UpdateModelResult\"5\n\x12\x44\x65leteModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteModelResponse\"\x16\n\x14PublishModelResponse\"5\n\x12GetMisclassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13GetMisclassResponse\x12J\n\x05table\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"7\n\x14\x44ownloadModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"$\n\x15\x44ownloadModelResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\x32\xc8\x1b\n\x0cModelService\x12\xac\x01\n\nListModels\x12\x42.github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest\x1a\x43.github.com.metaprov.modelaapi.services.model.v1.ListModelsResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/api/v1/model\x12\xb3\x01\n\x0b\x43reateModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.CreateModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.CreateModelResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/api/v1/models:\x01*\x12\xbd\x01\n\x08GetModel\x12@.github.com.metaprov.modelaapi.services.model.v1.GetModelRequest\x1a\x41.github.com.metaprov.modelaapi.services.model.v1.GetModelResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/models/{model.metadata.name}\x12\xc9\x01\n\x0bUpdateModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.UpdateModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.UpdateModelResponse\"/\x82\xd3\xe4\x93\x02)\x1a$/api/v1/models/{model.metadata.name}:\x01*\x12\xc6\x01\n\x0b\x44\x65leteModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.DeleteModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.DeleteModelResponse\",\x82\xd3\xe4\x93\x02&*$/api/v1/models/{model.metadata.name}\x12\xd0\x01\n\x0b\x44\x65ployModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.DeployModelResponse\"6\x82\xd3\xe4\x93\x02\x30\"+/api/v1/models/{model.metadata.name}:deploy:\x01*\x12\xd4\x01\n\x0cPublishModel\x12\x44.github.com.metaprov.modelaapi.services.model.v1.PublishModelRequest\x1a\x45.github.com.metaprov.modelaapi.services.model.v1.PublishModelResponse\"7\x82\xd3\xe4\x93\x02\x31\",/api/v1/models/{model.metadata.name}:publish:\x01*\x12\xe3\x01\n\x12\x43reateModelProfile\x12J.github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileRequest\x1aK.github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileResponse\"4\x82\xd3\xe4\x93\x02.\",/api/v1/models/{model.metadata.name}:profile\x12\xda\x01\n\x0fGetModelProfile\x12G.github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest\x1aH.github.com.metaprov.modelaapi.services.model.v1.GetModelProfileResponse\"4\x82\xd3\xe4\x93\x02.\",/api/v1/models/{model.metadata.name}:profile\x12\xd4\x01\n\x10GetModelMisclass\x12\x43.github.com.metaprov.modelaapi.services.model.v1.GetMisclassRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.GetMisclassResponse\"5\x82\xd3\xe4\x93\x02/\x12-/api/v1/models/{model.metadata.name}:misclass\x12\xce\x01\n\x0cGetModelLogs\x12\x44.github.com.metaprov.modelaapi.services.model.v1.GetModelLogsRequest\x1a\x45.github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/api/v1/models/{model.metadata.name}:logs\x12\xc9\x01\n\nAbortModel\x12\x42.github.com.metaprov.modelaapi.services.model.v1.AbortModelRequest\x1a\x43.github.com.metaprov.modelaapi.services.model.v1.AbortModelResponse\"2\x82\xd3\xe4\x93\x02,\"*/api/v1/models/{model.metadata.name}:abort\x12\xc9\x01\n\nPauseModel\x12\x42.github.com.metaprov.modelaapi.services.model.v1.PauseModelRequest\x1a\x43.github.com.metaprov.modelaapi.services.model.v1.PauseModelResponse\"2\x82\xd3\xe4\x93\x02,\"*/api/v1/models/{model.metadata.name}:pause\x12\xcd\x01\n\x0bResumeModel\x12\x43.github.com.metaprov.modelaapi.services.model.v1.ResumeModelRequest\x1a\x44.github.com.metaprov.modelaapi.services.model.v1.ResumeModelResponse\"3\x82\xd3\xe4\x93\x02-\"+/api/v1/models/{model.metadata.name}:resume\x12\xd4\x01\n\rCompareModels\x12\x45.github.com.metaprov.modelaapi.services.model.v1.CompareModelsRequest\x1a\x46.github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse\"4\x82\xd3\xe4\x93\x02.\",/api/v1/models/{model.metadata.name}:compare\x12\xd1\x01\n\x0c\x43ompileModel\x12\x44.github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest\x1a\x45.github.com.metaprov.modelaapi.services.model.v1.CompileModelResponse\"4\x82\xd3\xe4\x93\x02.\",/api/v1/models/{model.metadata.name}:compile\x12\xd5\x01\n\rDownloadModel\x12\x45.github.com.metaprov.modelaapi.services.model.v1.DownloadModelRequest\x1a\x46.github.com.metaprov.modelaapi.services.model.v1.DownloadModelResponse\"5\x82\xd3\xe4\x93\x02/\"-/api/v1/models/{model.metadata.name}:downloadB1Z/github.com/metaprov/modelaapi/services/model/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_CREATEMODELPROFILERESPONSE = _descriptor.Descriptor(
  name='CreateModelProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileResponse.uri', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=320,
)


_CREATEMODELPROFILEREQUEST = _descriptor.Descriptor(
  name='CreateModelProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=382,
)


_LISTMODELPROFILEREQUEST = _descriptor.Descriptor(
  name='ListModelProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=442,
)


_GETMODELPROFILEREQUEST = _descriptor.Descriptor(
  name='GetModelProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=514,
)


_GETMODELPROFILERESPONSE = _descriptor.Descriptor(
  name='GetModelProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelProfileResponse.profile', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=516,
  serialized_end=622,
)


_GETMODELLOGSRESPONSE_LOGSENTRY = _descriptor.Descriptor(
  name='LogsEntry',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.LogsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.LogsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.LogsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=787,
)

_GETMODELLOGSRESPONSE = _descriptor.Descriptor(
  name='GetModelLogsResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.logs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETMODELLOGSRESPONSE_LOGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=787,
)


_GETMODELLOGSREQUEST = _descriptor.Descriptor(
  name='GetModelLogsRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelLogsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=789,
  serialized_end=843,
)


_CREATEMODELREQUEST = _descriptor.Descriptor(
  name='CreateModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=944,
)


_CREATEMODELRESPONSE = _descriptor.Descriptor(
  name='CreateModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CreateModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=946,
  serialized_end=967,
)


_UPDATEMODELREQUEST = _descriptor.Descriptor(
  name='UpdateModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.UpdateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.model.v1.UpdateModelRequest.item', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1068,
)


_UPDATEMODELRESPONSE = _descriptor.Descriptor(
  name='UpdateModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.UpdateModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1091,
)


_GETMODELRESPONSE = _descriptor.Descriptor(
  name='GetModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1093,
  serialized_end=1204,
)


_ABORTMODELREQUEST = _descriptor.Descriptor(
  name='AbortModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.AbortModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.AbortModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.AbortModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1206,
  serialized_end=1258,
)


_ABORTMODELRESPONSE = _descriptor.Descriptor(
  name='AbortModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.AbortModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1260,
  serialized_end=1280,
)


_PAUSEMODELREQUEST = _descriptor.Descriptor(
  name='PauseModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.PauseModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.PauseModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.PauseModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1334,
)


_PAUSEMODELRESPONSE = _descriptor.Descriptor(
  name='PauseModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.PauseModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1336,
  serialized_end=1356,
)


_RESUMEMODELREQUEST = _descriptor.Descriptor(
  name='ResumeModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.ResumeModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.ResumeModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.ResumeModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1358,
  serialized_end=1411,
)


_RESUMEMODELRESPONSE = _descriptor.Descriptor(
  name='ResumeModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.ResumeModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1413,
  serialized_end=1434,
)


_COMPAREMODELSREQUEST = _descriptor.Descriptor(
  name='CompareModelsRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CompareModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.CompareModelsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.model.v1.CompareModelsRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1436,
  serialized_end=1492,
)


_COMPAREMODELSRESPONSE = _descriptor.Descriptor(
  name='CompareModelsResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profiles', full_name='github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse.profiles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1634,
)


_COMPILEMODELREQUEST = _descriptor.Descriptor(
  name='CompileModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest.target', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compiler', full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest.compiler', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1636,
  serialized_end=1724,
)


_COMPILEMODELRESPONSE = _descriptor.Descriptor(
  name='CompileModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.model.v1.CompileModelResponse.names', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1726,
  serialized_end=1782,
)


_DEPLOYMODELREQUEST = _descriptor.Descriptor(
  name='DeployModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predictor', full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest.predictor', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replicas', full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest.replicas', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic', full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest.traffic', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest.role', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1784,
  serialized_end=1905,
)


_PUBLISHMODELREQUEST = _descriptor.Descriptor(
  name='PublishModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.PublishModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.PublishModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.PublishModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1907,
  serialized_end=1961,
)


_DEPLOYMODELRESPONSE = _descriptor.Descriptor(
  name='DeployModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.DeployModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1963,
  serialized_end=1984,
)


_LISTMODELSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2123,
  serialized_end=2168,
)

_LISTMODELSREQUEST = _descriptor.Descriptor(
  name='ListModelsRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMODELSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1987,
  serialized_end=2168,
)


_LISTMODELSRESPONSE = _descriptor.Descriptor(
  name='ListModelsResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.model.v1.ListModelsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2170,
  serialized_end=2274,
)


_GETMODELREQUEST = _descriptor.Descriptor(
  name='GetModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.GetModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2276,
  serialized_end=2326,
)


_UPDATEMODELRESULT = _descriptor.Descriptor(
  name='UpdateModelResult',
  full_name='github.com.metaprov.modelaapi.services.model.v1.UpdateModelResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2328,
  serialized_end=2347,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
  name='DeleteModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.DeleteModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.DeleteModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.DeleteModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2349,
  serialized_end=2402,
)


_DELETEMODELRESPONSE = _descriptor.Descriptor(
  name='DeleteModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.DeleteModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2404,
  serialized_end=2425,
)


_PUBLISHMODELRESPONSE = _descriptor.Descriptor(
  name='PublishModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.PublishModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2427,
  serialized_end=2449,
)


_GETMISCLASSREQUEST = _descriptor.Descriptor(
  name='GetMisclassRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetMisclassRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.GetMisclassRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.GetMisclassRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2451,
  serialized_end=2504,
)


_GETMISCLASSRESPONSE = _descriptor.Descriptor(
  name='GetMisclassResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.GetMisclassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='github.com.metaprov.modelaapi.services.model.v1.GetMisclassResponse.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2506,
  serialized_end=2603,
)


_DOWNLOADMODELREQUEST = _descriptor.Descriptor(
  name='DownloadModelRequest',
  full_name='github.com.metaprov.modelaapi.services.model.v1.DownloadModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.model.v1.DownloadModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.model.v1.DownloadModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2605,
  serialized_end=2660,
)


_DOWNLOADMODELRESPONSE = _descriptor.Descriptor(
  name='DownloadModelResponse',
  full_name='github.com.metaprov.modelaapi.services.model.v1.DownloadModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='github.com.metaprov.modelaapi.services.model.v1.DownloadModelResponse.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2698,
)

_GETMODELPROFILERESPONSE.fields_by_name['profile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._MODELPROFILE
_GETMODELLOGSRESPONSE_LOGSENTRY.containing_type = _GETMODELLOGSRESPONSE
_GETMODELLOGSRESPONSE.fields_by_name['logs'].message_type = _GETMODELLOGSRESPONSE_LOGSENTRY
_CREATEMODELREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_UPDATEMODELREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_GETMODELRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_COMPAREMODELSRESPONSE.fields_by_name['profiles'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._MODELPROFILE
_LISTMODELSREQUEST_LABELSENTRY.containing_type = _LISTMODELSREQUEST
_LISTMODELSREQUEST.fields_by_name['labels'].message_type = _LISTMODELSREQUEST_LABELSENTRY
_LISTMODELSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELLIST
_GETMISCLASSRESPONSE.fields_by_name['table'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._TABLEVIEW
DESCRIPTOR.message_types_by_name['CreateModelProfileResponse'] = _CREATEMODELPROFILERESPONSE
DESCRIPTOR.message_types_by_name['CreateModelProfileRequest'] = _CREATEMODELPROFILEREQUEST
DESCRIPTOR.message_types_by_name['ListModelProfileRequest'] = _LISTMODELPROFILEREQUEST
DESCRIPTOR.message_types_by_name['GetModelProfileRequest'] = _GETMODELPROFILEREQUEST
DESCRIPTOR.message_types_by_name['GetModelProfileResponse'] = _GETMODELPROFILERESPONSE
DESCRIPTOR.message_types_by_name['GetModelLogsResponse'] = _GETMODELLOGSRESPONSE
DESCRIPTOR.message_types_by_name['GetModelLogsRequest'] = _GETMODELLOGSREQUEST
DESCRIPTOR.message_types_by_name['CreateModelRequest'] = _CREATEMODELREQUEST
DESCRIPTOR.message_types_by_name['CreateModelResponse'] = _CREATEMODELRESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelRequest'] = _UPDATEMODELREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelResponse'] = _UPDATEMODELRESPONSE
DESCRIPTOR.message_types_by_name['GetModelResponse'] = _GETMODELRESPONSE
DESCRIPTOR.message_types_by_name['AbortModelRequest'] = _ABORTMODELREQUEST
DESCRIPTOR.message_types_by_name['AbortModelResponse'] = _ABORTMODELRESPONSE
DESCRIPTOR.message_types_by_name['PauseModelRequest'] = _PAUSEMODELREQUEST
DESCRIPTOR.message_types_by_name['PauseModelResponse'] = _PAUSEMODELRESPONSE
DESCRIPTOR.message_types_by_name['ResumeModelRequest'] = _RESUMEMODELREQUEST
DESCRIPTOR.message_types_by_name['ResumeModelResponse'] = _RESUMEMODELRESPONSE
DESCRIPTOR.message_types_by_name['CompareModelsRequest'] = _COMPAREMODELSREQUEST
DESCRIPTOR.message_types_by_name['CompareModelsResponse'] = _COMPAREMODELSRESPONSE
DESCRIPTOR.message_types_by_name['CompileModelRequest'] = _COMPILEMODELREQUEST
DESCRIPTOR.message_types_by_name['CompileModelResponse'] = _COMPILEMODELRESPONSE
DESCRIPTOR.message_types_by_name['DeployModelRequest'] = _DEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name['PublishModelRequest'] = _PUBLISHMODELREQUEST
DESCRIPTOR.message_types_by_name['DeployModelResponse'] = _DEPLOYMODELRESPONSE
DESCRIPTOR.message_types_by_name['ListModelsRequest'] = _LISTMODELSREQUEST
DESCRIPTOR.message_types_by_name['ListModelsResponse'] = _LISTMODELSRESPONSE
DESCRIPTOR.message_types_by_name['GetModelRequest'] = _GETMODELREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelResult'] = _UPDATEMODELRESULT
DESCRIPTOR.message_types_by_name['DeleteModelRequest'] = _DELETEMODELREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelResponse'] = _DELETEMODELRESPONSE
DESCRIPTOR.message_types_by_name['PublishModelResponse'] = _PUBLISHMODELRESPONSE
DESCRIPTOR.message_types_by_name['GetMisclassRequest'] = _GETMISCLASSREQUEST
DESCRIPTOR.message_types_by_name['GetMisclassResponse'] = _GETMISCLASSRESPONSE
DESCRIPTOR.message_types_by_name['DownloadModelRequest'] = _DOWNLOADMODELREQUEST
DESCRIPTOR.message_types_by_name['DownloadModelResponse'] = _DOWNLOADMODELRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateModelProfileResponse = _reflection.GeneratedProtocolMessageType('CreateModelProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileResponse)
  })
_sym_db.RegisterMessage(CreateModelProfileResponse)

CreateModelProfileRequest = _reflection.GeneratedProtocolMessageType('CreateModelProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelProfileRequest)
  })
_sym_db.RegisterMessage(CreateModelProfileRequest)

ListModelProfileRequest = _reflection.GeneratedProtocolMessageType('ListModelProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelProfileRequest)
  })
_sym_db.RegisterMessage(ListModelProfileRequest)

GetModelProfileRequest = _reflection.GeneratedProtocolMessageType('GetModelProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelProfileRequest)
  })
_sym_db.RegisterMessage(GetModelProfileRequest)

GetModelProfileResponse = _reflection.GeneratedProtocolMessageType('GetModelProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelProfileResponse)
  })
_sym_db.RegisterMessage(GetModelProfileResponse)

GetModelLogsResponse = _reflection.GeneratedProtocolMessageType('GetModelLogsResponse', (_message.Message,), {

  'LogsEntry' : _reflection.GeneratedProtocolMessageType('LogsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMODELLOGSRESPONSE_LOGSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse.LogsEntry)
    })
  ,
  'DESCRIPTOR' : _GETMODELLOGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelLogsResponse)
  })
_sym_db.RegisterMessage(GetModelLogsResponse)
_sym_db.RegisterMessage(GetModelLogsResponse.LogsEntry)

GetModelLogsRequest = _reflection.GeneratedProtocolMessageType('GetModelLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELLOGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelLogsRequest)
  })
_sym_db.RegisterMessage(GetModelLogsRequest)

CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

CreateModelResponse = _reflection.GeneratedProtocolMessageType('CreateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CreateModelResponse)
  })
_sym_db.RegisterMessage(CreateModelResponse)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

UpdateModelResponse = _reflection.GeneratedProtocolMessageType('UpdateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.UpdateModelResponse)
  })
_sym_db.RegisterMessage(UpdateModelResponse)

GetModelResponse = _reflection.GeneratedProtocolMessageType('GetModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelResponse)
  })
_sym_db.RegisterMessage(GetModelResponse)

AbortModelRequest = _reflection.GeneratedProtocolMessageType('AbortModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.AbortModelRequest)
  })
_sym_db.RegisterMessage(AbortModelRequest)

AbortModelResponse = _reflection.GeneratedProtocolMessageType('AbortModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.AbortModelResponse)
  })
_sym_db.RegisterMessage(AbortModelResponse)

PauseModelRequest = _reflection.GeneratedProtocolMessageType('PauseModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PauseModelRequest)
  })
_sym_db.RegisterMessage(PauseModelRequest)

PauseModelResponse = _reflection.GeneratedProtocolMessageType('PauseModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PauseModelResponse)
  })
_sym_db.RegisterMessage(PauseModelResponse)

ResumeModelRequest = _reflection.GeneratedProtocolMessageType('ResumeModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ResumeModelRequest)
  })
_sym_db.RegisterMessage(ResumeModelRequest)

ResumeModelResponse = _reflection.GeneratedProtocolMessageType('ResumeModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ResumeModelResponse)
  })
_sym_db.RegisterMessage(ResumeModelResponse)

CompareModelsRequest = _reflection.GeneratedProtocolMessageType('CompareModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompareModelsRequest)
  })
_sym_db.RegisterMessage(CompareModelsRequest)

CompareModelsResponse = _reflection.GeneratedProtocolMessageType('CompareModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompareModelsResponse)
  })
_sym_db.RegisterMessage(CompareModelsResponse)

CompileModelRequest = _reflection.GeneratedProtocolMessageType('CompileModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPILEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompileModelRequest)
  })
_sym_db.RegisterMessage(CompileModelRequest)

CompileModelResponse = _reflection.GeneratedProtocolMessageType('CompileModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPILEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.CompileModelResponse)
  })
_sym_db.RegisterMessage(CompileModelResponse)

DeployModelRequest = _reflection.GeneratedProtocolMessageType('DeployModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeployModelRequest)
  })
_sym_db.RegisterMessage(DeployModelRequest)

PublishModelRequest = _reflection.GeneratedProtocolMessageType('PublishModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PublishModelRequest)
  })
_sym_db.RegisterMessage(PublishModelRequest)

DeployModelResponse = _reflection.GeneratedProtocolMessageType('DeployModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeployModelResponse)
  })
_sym_db.RegisterMessage(DeployModelResponse)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)
_sym_db.RegisterMessage(ListModelsRequest.LabelsEntry)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

UpdateModelResult = _reflection.GeneratedProtocolMessageType('UpdateModelResult', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELRESULT,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.UpdateModelResult)
  })
_sym_db.RegisterMessage(UpdateModelResult)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

DeleteModelResponse = _reflection.GeneratedProtocolMessageType('DeleteModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DeleteModelResponse)
  })
_sym_db.RegisterMessage(DeleteModelResponse)

PublishModelResponse = _reflection.GeneratedProtocolMessageType('PublishModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.PublishModelResponse)
  })
_sym_db.RegisterMessage(PublishModelResponse)

GetMisclassRequest = _reflection.GeneratedProtocolMessageType('GetMisclassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMISCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetMisclassRequest)
  })
_sym_db.RegisterMessage(GetMisclassRequest)

GetMisclassResponse = _reflection.GeneratedProtocolMessageType('GetMisclassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMISCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.GetMisclassResponse)
  })
_sym_db.RegisterMessage(GetMisclassResponse)

DownloadModelRequest = _reflection.GeneratedProtocolMessageType('DownloadModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DownloadModelRequest)
  })
_sym_db.RegisterMessage(DownloadModelRequest)

DownloadModelResponse = _reflection.GeneratedProtocolMessageType('DownloadModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.model.v1.model_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.model.v1.DownloadModelResponse)
  })
_sym_db.RegisterMessage(DownloadModelResponse)


DESCRIPTOR._options = None
_GETMODELLOGSRESPONSE_LOGSENTRY._options = None
_LISTMODELSREQUEST_LABELSENTRY._options = None

_MODELSERVICE = _descriptor.ServiceDescriptor(
  name='ModelService',
  full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2701,
  serialized_end=6229,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListModels',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.ListModels',
    index=0,
    containing_service=None,
    input_type=_LISTMODELSREQUEST,
    output_type=_LISTMODELSRESPONSE,
    serialized_options=b'\202\323\344\223\002\017\022\r/api/v1/model',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.CreateModel',
    index=1,
    containing_service=None,
    input_type=_CREATEMODELREQUEST,
    output_type=_CREATEMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\"\016/api/v1/models:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.GetModel',
    index=2,
    containing_service=None,
    input_type=_GETMODELREQUEST,
    output_type=_GETMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/api/v1/models/{model.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.UpdateModel',
    index=3,
    containing_service=None,
    input_type=_UPDATEMODELREQUEST,
    output_type=_UPDATEMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002)\032$/api/v1/models/{model.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.DeleteModel',
    index=4,
    containing_service=None,
    input_type=_DELETEMODELREQUEST,
    output_type=_DELETEMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002&*$/api/v1/models/{model.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeployModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.DeployModel',
    index=5,
    containing_service=None,
    input_type=_DEPLOYMODELREQUEST,
    output_type=_DEPLOYMODELRESPONSE,
    serialized_options=b'\202\323\344\223\0020\"+/api/v1/models/{model.metadata.name}:deploy:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PublishModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.PublishModel',
    index=6,
    containing_service=None,
    input_type=_PUBLISHMODELREQUEST,
    output_type=_PUBLISHMODELRESPONSE,
    serialized_options=b'\202\323\344\223\0021\",/api/v1/models/{model.metadata.name}:publish:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelProfile',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.CreateModelProfile',
    index=7,
    containing_service=None,
    input_type=_CREATEMODELPROFILEREQUEST,
    output_type=_CREATEMODELPROFILERESPONSE,
    serialized_options=b'\202\323\344\223\002.\",/api/v1/models/{model.metadata.name}:profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelProfile',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.GetModelProfile',
    index=8,
    containing_service=None,
    input_type=_GETMODELPROFILEREQUEST,
    output_type=_GETMODELPROFILERESPONSE,
    serialized_options=b'\202\323\344\223\002.\",/api/v1/models/{model.metadata.name}:profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelMisclass',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.GetModelMisclass',
    index=9,
    containing_service=None,
    input_type=_GETMISCLASSREQUEST,
    output_type=_GETMISCLASSRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/api/v1/models/{model.metadata.name}:misclass',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelLogs',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.GetModelLogs',
    index=10,
    containing_service=None,
    input_type=_GETMODELLOGSREQUEST,
    output_type=_GETMODELLOGSRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/api/v1/models/{model.metadata.name}:logs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.AbortModel',
    index=11,
    containing_service=None,
    input_type=_ABORTMODELREQUEST,
    output_type=_ABORTMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002,\"*/api/v1/models/{model.metadata.name}:abort',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.PauseModel',
    index=12,
    containing_service=None,
    input_type=_PAUSEMODELREQUEST,
    output_type=_PAUSEMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002,\"*/api/v1/models/{model.metadata.name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.ResumeModel',
    index=13,
    containing_service=None,
    input_type=_RESUMEMODELREQUEST,
    output_type=_RESUMEMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002-\"+/api/v1/models/{model.metadata.name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompareModels',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.CompareModels',
    index=14,
    containing_service=None,
    input_type=_COMPAREMODELSREQUEST,
    output_type=_COMPAREMODELSRESPONSE,
    serialized_options=b'\202\323\344\223\002.\",/api/v1/models/{model.metadata.name}:compare',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompileModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.CompileModel',
    index=15,
    containing_service=None,
    input_type=_COMPILEMODELREQUEST,
    output_type=_COMPILEMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002.\",/api/v1/models/{model.metadata.name}:compile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadModel',
    full_name='github.com.metaprov.modelaapi.services.model.v1.ModelService.DownloadModel',
    index=16,
    containing_service=None,
    input_type=_DOWNLOADMODELREQUEST,
    output_type=_DOWNLOADMODELRESPONSE,
    serialized_options=b'\202\323\344\223\002/\"-/api/v1/models/{model.metadata.name}:download',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELSERVICE)

DESCRIPTOR.services_by_name['ModelService'] = _MODELSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/labelingpipelinerun/v1/labelingpipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/labelingpipelinerun/v1/labelingpipelinerun.proto',
  package='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1',
  syntax='proto3',
  serialized_options=b'Z=github.com/metaprov/modelaapi/services/labelingpipelinerun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nWgithub.com/metaprov/modelaapi/services/labelingpipelinerun/v1/labelingpipelinerun.proto\x12=github.com.metaprov.modelaapi.services.labelingpipelinerun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xdd\x01\n\x1eListLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12y\n\x06labels\x18\x02 \x03(\x0b\x32i.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x1fListLabelingPipelineRunResponse\x12\\\n\x05items\x18\x01 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunList\"{\n CreateLabelingPipelineRunRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"#\n!CreateLabelingPipelineRunResponse\"{\n UpdateLabelingPipelineRunRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"#\n!UpdateLabelingPipelineRunResponse\"@\n\x1dGetLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x87\x01\n\x1eGetLabelingPipelineRunResponse\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"C\n DeleteLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"#\n!DeleteLabelingPipelineRunResponse2\x9d\n\n\x1aLabelingPipelineRunService\x12\xfb\x01\n\x18ListLabelingPipelineRuns\x12].github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/labelingpipelineruns\x12\x83\x02\n\x19\x43reateLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/labelingpipelineruns:\x01*\x12\xfe\x01\n\x16GetLabelingPipelineRun\x12\\.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest\x1a].github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/labelingpipelineruns/{name}\x12\x96\x02\n\x19UpdateLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunResponse\"6\x82\xd3\xe4\x93\x02\x30\x1a+/v1/labelingpipelines/{label.metadata.name}:\x01*\x12\xe0\x01\n\x19\x44\x65leteLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunResponse\"\x00\x42?Z=github.com/metaprov/modelaapi/services/labelingpipelinerun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=476,
)

_LISTLABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='ListLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=255,
  serialized_end=476,
)


_LISTLABELINGPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='ListLabelingPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=605,
)


_CREATELABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=730,
)


_CREATELABELINGPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='CreateLabelingPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=732,
  serialized_end=767,
)


_UPDATELABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=892,
)


_UPDATELABELINGPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateLabelingPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=929,
)


_GETLABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=995,
)


_GETLABELINGPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='GetLabelingPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1133,
)


_DELETELABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1202,
)


_DELETELABELINGPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteLabelingPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1204,
  serialized_end=1239,
)

_LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY.containing_type = _LISTLABELINGPIPELINERUNREQUEST
_LISTLABELINGPIPELINERUNREQUEST.fields_by_name['labels'].message_type = _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY
_LISTLABELINGPIPELINERUNRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUNLIST
_CREATELABELINGPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN
_UPDATELABELINGPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN
_GETLABELINGPIPELINERUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN
DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunRequest'] = _LISTLABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunResponse'] = _LISTLABELINGPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunRequest'] = _CREATELABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunResponse'] = _CREATELABELINGPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunRequest'] = _UPDATELABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunResponse'] = _UPDATELABELINGPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunRequest'] = _GETLABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunResponse'] = _GETLABELINGPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunRequest'] = _DELETELABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunResponse'] = _DELETELABELINGPIPELINERUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunRequest)
_sym_db.RegisterMessage(ListLabelingPipelineRunRequest.LabelsEntry)

ListLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunResponse)

CreateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunRequest)

CreateLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunResponse)

UpdateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunRequest)

UpdateLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunResponse)

GetLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunRequest)

GetLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunResponse)

DeleteLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunRequest)

DeleteLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunResponse)


DESCRIPTOR._options = None
_LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._options = None

_LABELINGPIPELINERUNSERVICE = _descriptor.ServiceDescriptor(
  name='LabelingPipelineRunService',
  full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1242,
  serialized_end=2551,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListLabelingPipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService.ListLabelingPipelineRuns',
    index=0,
    containing_service=None,
    input_type=_LISTLABELINGPIPELINERUNREQUEST,
    output_type=_LISTLABELINGPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/v1/labelingpipelineruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService.CreateLabelingPipelineRun',
    index=1,
    containing_service=None,
    input_type=_CREATELABELINGPIPELINERUNREQUEST,
    output_type=_CREATELABELINGPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\030/v1/labelingpipelineruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService.GetLabelingPipelineRun',
    index=2,
    containing_service=None,
    input_type=_GETLABELINGPIPELINERUNREQUEST,
    output_type=_GETLABELINGPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/v1/labelingpipelineruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService.UpdateLabelingPipelineRun',
    index=3,
    containing_service=None,
    input_type=_UPDATELABELINGPIPELINERUNREQUEST,
    output_type=_UPDATELABELINGPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\0020\032+/v1/labelingpipelines/{label.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.LabelingPipelineRunService.DeleteLabelingPipelineRun',
    index=4,
    containing_service=None,
    input_type=_DELETELABELINGPIPELINERUNREQUEST,
    output_type=_DELETELABELINGPIPELINERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LABELINGPIPELINERUNSERVICE)

DESCRIPTOR.services_by_name['LabelingPipelineRunService'] = _LABELINGPIPELINERUNSERVICE

# @@protoc_insertion_point(module_scope)
